#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const download_1 = require("./commands/download");
const help_1 = require("./commands/help");
const init_1 = require("./commands/init");
const postinstall_1 = require("./commands/postinstall");
const validate_1 = require("./commands/validate");
const logger_1 = require("./helpers/logger");
async function run(argv, cwd, logger) {
    // So far no command takes any further arguments.
    // Let each command handle this when needed.
    if (argv.length > 1) {
        logger.error(`Expected no extra arguments but got: ${argv.slice(1).join(" ")}`);
        return 1;
    }
    switch (argv[0]) {
        case undefined:
        case "-h":
        case "-help":
        case "--help":
        case "help":
            logger.log(help_1.default(cwd));
            return 0;
        case "init":
            return await init_1.default(cwd, logger);
        case "validate":
            return validate_1.default(cwd, logger);
        case "download": {
            const result = await download_1.default(cwd, logger);
            switch (result.tag) {
                case "Exit":
                    return result.statusCode;
                case "Success":
                    return 0;
            }
        }
        case "postinstall":
            return await postinstall_1.default(cwd, logger);
        default:
            logger.error(`Unknown command: ${argv[0]}`);
            return 1;
    }
}
run(process.argv.slice(2), process.cwd(), logger_1.logger).then((exitCode) => {
    process.exit(exitCode);
}, (error) => {
    logger_1.logger.error(`Unexpected error:\n${error.stack || error.message}`);
    process.exit(1);
});
